@@ -1,5 +1,6 @@
 var NAVTREEINDEX41 =
 {
+"interfacecom_1_1sun_1_1star_1_1awt_1_1XDateField.html#adadc176dabaf064f68b20c15325b2908":[2,0,0,0,0,19,192,15],
 "interfacecom_1_1sun_1_1star_1_1awt_1_1XDateField.html#adadc176dabaf064f68b20c15325b2908":[3,0,0,0,0,19,153,15],
 "interfacecom_1_1sun_1_1star_1_1awt_1_1XDateField.html#aeec358934ed3090e66abf4668a02c192":[2,0,0,0,0,19,192,2],
 "interfacecom_1_1sun_1_1star_1_1awt_1_1XDateField.html#aeec358934ed3090e66abf4668a02c192":[3,0,0,0,0,19,153,2],
@@ -248,6 +249,5 @@ var NAVTREEINDEX41 =
 "interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a7199165a0bb06a40b59e8eeabff9ee25":[2,0,0,0,0,19,214,6],
 "interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a7199165a0bb06a40b59e8eeabff9ee25":[3,0,0,0,0,19,175,6],
 "interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a8554b44445ddb7337ea518872014e3a9":[2,0,0,0,0,19,214,2],
-"interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a8554b44445ddb7337ea518872014e3a9":[3,0,0,0,0,19,175,2],
-"interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a98b45e0a7ed122b6710df00209b67827":[2,0,0,0,0,19,214,20]
+"interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a8554b44445ddb7337ea518872014e3a9":[3,0,0,0,0,19,175,2]
 };
