@@ -1,18 +1,5 @@
 var NAVTREEINDEX90 =
 {
-"interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheetDocument.html":[3,0,0,0,0,59,274],
-"interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheetDocument.html#a3ea7cfcc41c4d4690228e62ca4a6a55d":[2,0,0,0,0,60,313,0],
-"interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheetDocument.html#a3ea7cfcc41c4d4690228e62ca4a6a55d":[3,0,0,0,0,59,274,0],
-"interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheetView.html":[2,0,0,0,0,60,316],
-"interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheetView.html":[3,0,0,0,0,59,277],
-"interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheetView.html#a302d3c48c1cdd2c6ca0f5093f1969741":[2,0,0,0,0,60,316,1],
-"interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheetView.html#a302d3c48c1cdd2c6ca0f5093f1969741":[3,0,0,0,0,59,277,1],
-"interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheetView.html#a493b714a8ce67e566011a3809ba87231":[2,0,0,0,0,60,316,0],
-"interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheetView.html#a493b714a8ce67e566011a3809ba87231":[3,0,0,0,0,59,277,0],
-"interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheets.html":[2,0,0,0,0,60,314],
-"interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheets.html":[3,0,0,0,0,59,275],
-"interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheets.html#a08826fc68bcb5a1c13f9e13102b30e35":[2,0,0,0,0,60,314,2],
-"interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheets.html#a08826fc68bcb5a1c13f9e13102b30e35":[3,0,0,0,0,59,275,2],
 "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheets.html#a920aee3cc061fb6c1a018583354a004a":[2,0,0,0,0,60,314,0],
 "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheets.html#a920aee3cc061fb6c1a018583354a004a":[3,0,0,0,0,59,275,0],
 "interfacecom_1_1sun_1_1star_1_1sheet_1_1XSpreadsheets.html#ab235b8c33bafa71d643f127b4758655e":[2,0,0,0,0,60,314,1],
@@ -249,5 +236,18 @@ var NAVTREEINDEX90 =
 "interfacecom_1_1sun_1_1star_1_1svg_1_1XSVGPrinter.html#af03cfac8d9d1c9bc58b635dec396c0a5":[3,0,0,0,0,62,0,2],
 "interfacecom_1_1sun_1_1star_1_1svg_1_1XSVGWriter.html":[2,0,0,0,0,63,1],
 "interfacecom_1_1sun_1_1star_1_1svg_1_1XSVGWriter.html":[3,0,0,0,0,62,1],
-"interfacecom_1_1sun_1_1star_1_1svg_1_1XSVGWriter.html#acf7872c58d7b19343a1c7837d73fb851":[2,0,0,0,0,63,1,0]
+"interfacecom_1_1sun_1_1star_1_1svg_1_1XSVGWriter.html#acf7872c58d7b19343a1c7837d73fb851":[2,0,0,0,0,63,1,0],
+"interfacecom_1_1sun_1_1star_1_1svg_1_1XSVGWriter.html#acf7872c58d7b19343a1c7837d73fb851":[3,0,0,0,0,62,1,0],
+"interfacecom_1_1sun_1_1star_1_1system_1_1XSimpleMailClient.html":[2,0,0,0,0,64,7],
+"interfacecom_1_1sun_1_1star_1_1system_1_1XSimpleMailClient.html":[3,0,0,0,0,63,5],
+"interfacecom_1_1sun_1_1star_1_1system_1_1XSimpleMailClient.html#acfc1564bde1d4153547b1a1862ccf7d6":[2,0,0,0,0,64,7,1],
+"interfacecom_1_1sun_1_1star_1_1system_1_1XSimpleMailClient.html#acfc1564bde1d4153547b1a1862ccf7d6":[3,0,0,0,0,63,5,1],
+"interfacecom_1_1sun_1_1star_1_1system_1_1XSimpleMailClient.html#afd43b18eada3c84dbdb793e10916ba68":[2,0,0,0,0,64,7,0],
+"interfacecom_1_1sun_1_1star_1_1system_1_1XSimpleMailClient.html#afd43b18eada3c84dbdb793e10916ba68":[3,0,0,0,0,63,5,0],
+"interfacecom_1_1sun_1_1star_1_1system_1_1XSimpleMailClientSupplier.html":[2,0,0,0,0,64,8],
+"interfacecom_1_1sun_1_1star_1_1system_1_1XSimpleMailClientSupplier.html":[3,0,0,0,0,63,6],
+"interfacecom_1_1sun_1_1star_1_1system_1_1XSimpleMailClientSupplier.html#a219f5a33bfdac571c5297a1f1a4189bf":[2,0,0,0,0,64,8,0],
+"interfacecom_1_1sun_1_1star_1_1system_1_1XSimpleMailClientSupplier.html#a219f5a33bfdac571c5297a1f1a4189bf":[3,0,0,0,0,63,6,0],
+"interfacecom_1_1sun_1_1star_1_1system_1_1XSimpleMailMessage.html":[2,0,0,0,0,64,9],
+"interfacecom_1_1sun_1_1star_1_1system_1_1XSimpleMailMessage.html":[3,0,0,0,0,63,7]
 };
